@@ -2,8 +2,8 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2017 Luis Falcon <falcon@gnu.org>
-#    Copyright (C) 2011-2017 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2019 Luis Falcon <falcon@gnu.org>
+#    Copyright (C) 2011-2019 GNU Solidario <health@gnusolidario.org>
 #
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -21,27 +21,101 @@
 #
 ##############################################################################
 from datetime import datetime
-from trytond.model import ModelView, ModelSingleton, ModelSQL, fields, Unique
+from trytond.model import ModelView, ModelSingleton, ModelSQL, fields, \
+    Unique, ValueMixin
 from trytond.transaction import Transaction
 from trytond.pool import Pool
+from trytond import backend
+from trytond.tools.multivalue import migrate_property
 
 
-__all__ = ['GnuHealthSequences', 'PatientData', 'TestType', 'Lab',
+__all__ = ['GnuHealthSequences', 'GnuHealthSequenceSetup',
+    'PatientData', 'TestType', 'Lab',
     'GnuHealthLabTestUnits', 'GnuHealthTestCritearea',
     'GnuHealthPatientLabTest']
 
+sequences = ['lab_sequence', 'lab_request_sequence']
 
 class GnuHealthSequences(ModelSingleton, ModelSQL, ModelView):
     "Standard Sequences for GNU Health"
     __name__ = "gnuhealth.sequences"
 
-    lab_sequence = fields.Property(fields.Many2One('ir.sequence',
+    lab_sequence = fields.MultiValue(fields.Many2One('ir.sequence',
         'Lab Sequence', domain=[('code', '=', 'gnuhealth.lab')],
         required=True))
-    lab_request_sequence = fields.Property(fields.Many2One('ir.sequence',
+    lab_request_sequence = fields.MultiValue(fields.Many2One('ir.sequence',
         'Patient Lab Request Sequence', required=True,
         domain=[('code', '=', 'gnuhealth.patient.lab.test')]))
 
+    @classmethod
+    def multivalue_model(cls, field):
+        pool = Pool()
+
+        if field in sequences:
+            return pool.get('gnuhealth.sequence.setup')
+        return super(GnuHealthSequences, cls).multivalue_model(field)
+
+
+    @classmethod
+    def default_lab_request_sequence(cls):
+        return cls.multivalue_model(
+            'lab_request_sequence').default_lab_request_sequence()
+
+    @classmethod
+    def default_lab_sequence(cls):
+        return cls.multivalue_model(
+            'lab_sequence').default_lab_sequence()
+
+
+# SEQUENCE SETUP
+class GnuHealthSequenceSetup(ModelSQL, ValueMixin):
+    'GNU Health Sequences Setup'
+    __name__ = 'gnuhealth.sequence.setup'
+
+    lab_request_sequence = fields.Many2One('ir.sequence', 
+        'Lab Request Sequence', required=True,
+        domain=[('code', '=', 'gnuhealth.patient.lab.test')])
+
+
+    lab_sequence = fields.Many2One('ir.sequence', 
+        'Lab Result Sequence', required=True,
+        domain=[('code', '=', 'gnuhealth.lab')])
+  
+    @classmethod
+    def __register__(cls, module_name):
+        TableHandler = backend.get('TableHandler')
+        exist = TableHandler.table_exist(cls._table)
+
+        super(GnuHealthSequenceSetup, cls).__register__(module_name)
+
+        if not exist:
+            cls._migrate_MultiValue([], [], [])
+
+    @classmethod
+    def _migrate_property(cls, field_names, value_names, fields):
+        field_names.extend(sequences)
+        value_names.extend(sequences)
+        migrate_property(
+            'gnuhealth.sequences', field_names, cls, value_names,
+            fields=fields)
+
+    @classmethod
+    def default_lab_request_sequence(cls):
+        pool = Pool()
+        ModelData = pool.get('ir.model.data')
+        return ModelData.get_id(
+            'health_lab', 'seq_gnuhealth_lab_request')
+
+    @classmethod
+    def default_lab_sequence(cls):
+        pool = Pool()
+        ModelData = pool.get('ir.model.data')
+        return ModelData.get_id(
+            'health_lab', 'seq_gnuhealth_lab_test')
+    
+# END SEQUENCE SETUP , MIGRATION FROM FIELDS.MultiValue
+
+
 
 class PatientData(ModelSQL, ModelView):
     'Patient lab tests'
@@ -65,6 +139,12 @@ class TestType(ModelSQL, ModelView):
     critearea = fields.One2Many('gnuhealth.lab.test.critearea', 'test_type_id',
         'Test Cases')
 
+    active = fields.Boolean('Active', select=True)
+
+    @staticmethod
+    def default_active():
+        return True
+
     @classmethod
     def __setup__(cls):
         super(TestType, cls).__setup__()
@@ -93,7 +173,7 @@ class TestType(ModelSQL, ModelView):
 
 
 class Lab(ModelSQL, ModelView):
-    'Lab Test'
+    'Patient Lab Test Results'
     __name__ = 'gnuhealth.lab'
 
     name = fields.Char('ID', help="Lab result ID", readonly=True)
@@ -112,6 +192,25 @@ class Lab(ModelSQL, ModelView):
     date_requested = fields.DateTime('Date requested', required=True,
         select=True)
     date_analysis = fields.DateTime('Date of the Analysis', select=True)
+    request_order = fields.Integer('Request', readonly=True)
+
+    analytes_summary = \
+        fields.Function(fields.Text('Summary'),
+         'get_analytes_summary')
+
+    def get_analytes_summary(self, name):
+            summ = ""
+            for analyte in self.critearea:
+                if analyte.result or analyte.result_text:
+                    res = ""
+                    res_text = ""
+                    if analyte.result_text:
+                        res_text = analyte.result_text
+                    if analyte.result:
+                        res = str(analyte.result) + " "
+                    summ = summ + analyte.rec_name + " "  + \
+                        res +  res_text + "\n"
+            return summ
 
     @classmethod
     def __setup__(cls):
@@ -121,6 +220,8 @@ class Lab(ModelSQL, ModelView):
             ('id_uniq', Unique(t, t.name),
              'The test ID code must be unique')
         ]
+        cls._order.insert(0, ('date_requested', 'DESC'))
+
 
     @staticmethod
     def default_date_requested():
@@ -144,6 +245,16 @@ class Lab(ModelSQL, ModelView):
 
         return super(Lab, cls).create(vlist)
 
+    @classmethod
+    def search_rec_name(cls, name, clause):
+        if clause[1].startswith('!') or clause[1].startswith('not '):
+            bool_op = 'AND'
+        else:
+            bool_op = 'OR'
+        return [bool_op,
+            ('patient',) + tuple(clause[1:]),
+            ('name',) + tuple(clause[1:]),
+            ]
 
 class GnuHealthLabTestUnits(ModelSQL, ModelView):
     'Lab Test Units'
@@ -217,9 +328,13 @@ class GnuHealthTestCritearea(ModelSQL, ModelView):
 
     @fields.depends('result', 'lower_limit', 'upper_limit')
     def on_change_with_warning(self):
-        if (self.result < self.lower_limit or self.result > self.upper_limit):
-            return True
-        return False
+        if (self.result and self.lower_limit):
+            if (self.result < self.lower_limit):
+                return True
+
+        if (self.result and self.upper_limit):
+            if (self.result > self.upper_limit):
+                return True
 
     @classmethod
     def check_xml_record(cls, records, values):
@@ -229,7 +344,7 @@ class GnuHealthTestCritearea(ModelSQL, ModelView):
 class GnuHealthPatientLabTest(ModelSQL, ModelView):
     'Patient Lab Test'
     __name__ = 'gnuhealth.patient.lab.test'
-
+    
     name = fields.Many2One('gnuhealth.lab.test_type', 'Test Type',
         required=True, select=True)
     date = fields.DateTime('Date', select=True)
@@ -243,7 +358,7 @@ class GnuHealthPatientLabTest(ModelSQL, ModelView):
      select=True)
     doctor_id = fields.Many2One('gnuhealth.healthprofessional', 'Doctor',
         help="Doctor who Request the lab test.", select=True)
-    request = fields.Integer('Request', readonly=True)
+    request = fields.Integer('Order', readonly=True)
     urgent = fields.Boolean('Urgent')
 
     @classmethod
