@@ -2,8 +2,8 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2017 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2017 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2019 Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2011-2019 GNU Solidario <health@gnusolidario.org>
 #
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -22,10 +22,11 @@
 ##############################################################################
 
 from trytond.pool import Pool
-from health_ntd_dengue import *
+from .health_ntd_dengue import *
 
 def register():
     Pool.register(
         DengueDUSurvey,
         GnuHealthSequences,
+        GnuHealthSequenceSetup,
         module='health_ntd_dengue', type_='model')
