@@ -1,5 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
+#    Copyright (C) 2011-2019 Luis Falcon <falcon@gnu.org>
 #    Copyright (C) 2011 Cédric Krier
 
 #    This program is free software: you can redistribute it and/or modify
@@ -18,52 +19,57 @@
 from setuptools import setup
 import re
 import os
-import ConfigParser
+import configparser
 
 def read(fname):
-    return open(os.path.join(os.path.dirname(__file__), fname)).read()
+    return open(os.path.join(os.path.dirname(__file__), fname), encoding="UTF-8").read()
 
-config = ConfigParser.ConfigParser()
+config = configparser.ConfigParser()
 config.readfp(open('tryton.cfg'))
 info = dict(config.items('tryton'))
 
 for key in ('depends', 'extras_depend', 'xml'):
     if key in info:
         info[key] = info[key].strip().splitlines()
-major_version, minor_version = 3, 8
+major_version, minor_version = 4, 6
 
 requires = []
 
 for dep in info.get('depends', []):
-    if dep.startswith('health'):
-        requires.append('trytond_%s == %s' %
-            (dep, info.get('version')))
-    elif not re.match(r'(ir|res|webdav)(\W|$)', dep):
-        requires.append('trytond_%s >= %s.%s, < %s.%s' %
-            (dep, major_version, minor_version, major_version,
-                minor_version + 1))
-requires.append('trytond >= %s.%s, < %s.%s' %
-    (major_version, minor_version, major_version, minor_version + 1))
+    if (dep == 'health'):
+        requires.append('gnuhealth == %s' % (info.get('version')))
 
-setup(name='trytond_health_pediatrics_growth_charts_who',
+    elif dep.startswith('health_'):
+        health_package = dep.split('_',1)[1]
+        requires.append('gnuhealth_%s == %s' %
+            (health_package, info.get('version')))
+    else: 
+        if not re.match(r'(ir|res|webdav)(\W|$)', dep):
+            requires.append('trytond_%s >= %s.%s, < %s.%s' %
+                (dep, major_version, minor_version, major_version,
+                    minor_version + 1))
+
+setup(name='gnuhealth_pediatrics_growth_charts_who',
     version=info.get('version', '0.0.1'),
-    description=info.get('description', 'GNU Health Pediatrics Growth Charts WHO Module'),
-    author=info.get('author', 'GNU Solidario'),
-    author_email=info.get('email', 'health@gnusolidario.org'),
-    url=info.get('website', 'http://health.gnu.org/'),
+    description=info.get('description', 'GNU Health Pediatrics growth charts - WHO Module'),
+    long_description=read('README'),
+    author='GNU Solidario',
+    author_email='health@gnusolidario.org',
+    url='http://health.gnu.org',
     download_url='http://ftp.gnu.org/gnu/health/',
     package_dir={'trytond.modules.health_pediatrics_growth_charts_who': '.'},
     packages=[
         'trytond.modules.health_pediatrics_growth_charts_who',
+        'trytond.modules.health_pediatrics_growth_charts_who.tests',
         'trytond.modules.health_pediatrics_growth_charts_who.wizard',
         'trytond.modules.health_pediatrics_growth_charts_who.report',
-        'trytond.modules.health_pediatrics_growth_charts_who.tests',
         ],
+
     package_data={
-        'trytond.modules.health_pediatrics_growth_charts_who': info.get(
-            'xml', []) + info.get('translation', []) + ['tryton.cfg',
-            'view/*.xml','doc/*.rst', 'locale/*.po', 'report/*.odt', 
-            'icons/*.svg'],
+        'trytond.modules.health_pediatrics_growth_charts_who': info.get('xml', []) \
+            + info.get('translation', []) \
+            + ['tryton.cfg', 'view/*.xml', 'doc/*.rst', 'locale/*.po',
+               'report/*.odt', 'icons/*.svg'],
         },
 
     classifiers=[
@@ -76,7 +82,7 @@ setup(name='trytond_health_pediatrics_growth_charts_who',
         'Natural Language :: English',
         'Natural Language :: Spanish',
         'Operating System :: OS Independent',
-        'Programming Language :: Python :: 2.7',
+        'Programming Language :: Python :: 3',
         'Topic :: Scientific/Engineering :: Bio-Informatics',
         'Topic :: Scientific/Engineering :: Medical Science Apps.',
         ],
